\name{num.sv}
\alias{num.sv}
\title{Estimate number of surrogate variables to include in analysis}
\description{
  Estimate number of important surrogate variables from a gene expression 
  data set. 
}
\usage{
  num.sv(dat, mod, B=20, sv.sig=0.10, method=c("leek","be"), seed=NULL)
}
\arguments{
  \item{dat}{A m genes by n arrays matrix of expression data}
  \item{mod}{A n by k model matrix corresponding to the primary model fit   
  (see model.matrix)}
  \item{B}{The number of null iterations to perform.}
  \item{sv.sig}{The significance cutoff for eigengenes.}
  \item{method}{The method to use for estimating surrogate variables, for now
  there is only one option (based ib Buja and Eyuboglu 1992). }
  \item{seed}{A numeric seed for reproducible results. Optional.} 
}
\details{
  The model matrix should include a column for an intercept. num.sv
  estimates the number of surrogate variables to include in the analysis
  as described in Leek and Storey (2007), based on the permutation
  test of Buja and Eyuboglu (1992). 
}


\value{
  A list containing:
  \item{n.sv}{The number of significant surrogate variables}
  \item{p.sv}{The p-values for each eigengene} 

}
\references{
   Buja A and Eyuboglu N. (1992) Remarks on parrallel analysis. Multivariate
   Behavioral Research, 27(4), 509-540
 
   Leek JT and Storey JD. (2008) A general framework for multiple testing 
   dependence. Proceedings of the National Academy of Sciences, 105: 
   18718-18723. \url{http://www.biostat.jhsph.edu/~jleek/publications.html}

   Leek JT and Storey JD. (2007) Capturing heterogeneity in gene expression 
   studies by surrogate variable analysis. PLoS Genetics, 3: e161. 
   \url{http://www.biostat.jhsph.edu/~jleek/publications.html}
 
  SVA Manual \url{http://www.biostat.jhsph.edu/~jleek/sva/manual.pdf}
}

\author{Jeffrey T. Leek \email{jleek@jhsph.edu}, John Storey \email{jstorey@princeton.edu}}
\seealso{\code{\link{sva}}, \code{\link{irwsva.build}},\code{\link{twostepsva.build}} }
\examples{
  \dontrun{
  
  ## Load data
  data(svadat)
  grp <- rep(c(0,1),each=10)
  mod <- model.matrix(~1+grp)

  ## Calculate the number of surrogate variables 
  xx <- num.sv(svadat,mod)
  xx$n.sv
 
 }
}

\keyword{misc}


